generate_signing_key

Function generate_signing_key 

pub fn generate_signing_key() -> SigningKey
Generate a new signing key for use with the encode_cookie and decode_cookie functions.

This uses the thread-local random number generator, which is guaranteed by the rand crate to produce cryptographically secure random data.