pub type SigningKey = [u8; 32];Expand description
Key used to sign, encrypt, decrypt & verify your cookies
The signing key should be cryptographically secure random data. You can use generate_signing_key to safely make a signing key, or you can generate it yourself as long as you make sure the randomness is cryptographically secure. This signing key may be stored in a secure location and loaded at startup if you like. You might want to store & load if:
- Cookie based sessions should out-last server restarts
- The same cookie needs to be read by separate instances of the server in horizontal scaling situations
- The cookie needs to be read by an entirely separate unrelated server (say, a caching server or something)