pub fn generate_signing_key() -> SigningKeyExpand description
Generate a new signing key for use with the encode_cookie and decode_cookie functions.
This uses the thread-local random number generator, which is guaranteed by the rand crate to produce cryptographically secure random data.